@@ -8,7 +8,6 @@ class RedisClient(ABC):
         self.db=db
         self.charset=charset
         self.decode_responses=decode_responses
-        return
         self.redis=redis.Redis(
             host=self.host,
             port=self.port,
@@ -16,7 +15,7 @@ class RedisClient(ABC):
             charset=self.charset,
             decode_responses=self.decode_responses
         )
-    
+
     def set(
         self,
         arrayName:str,
@@ -25,11 +24,11 @@ class RedisClient(ABC):
     ):
         self.redis.hset(arrayName, key, value)
 
-    def get(self, arrayName:str):
+    def get(self, arrayName:str) -> list:
         return self.redis.hgetall(arrayName)
 
-    def _getRedisClient(self):
+    def _getRedisClient(self) -> redis.Redis:
         return self.redis
 
-    def getHost(self):
-        return self.host
\ No newline at end of file
+    def getHost(self) -> str:
+        return self.host
