@@ -1,22 +1,14 @@
-# import pandas as pd
-
-# def getDataframe(query:str):
-#     try:
-#         df = pd.read_sql(query, con)
-#         return df
-#     except Exception as e:
-#         print(e)
-#         return None
-        
+       
 def guessMetricByType(mainDict:dict, checkDict:dict):
-    if "units" not in mainDict:
-        mainDict = {}
-    for i in checkDict:
-        try:
-            int(checkDict[i])
-            mainDict[i] = 'count'
-        except ValueError:
-            mainDict[i] = 'string'
+   if "units" not in mainDict:
+      mainDict = {}
+   for i in checkDict:
+      try:
+         int(checkDict[i])
+         mainDict[i] = 'count'
+      except ValueError:
+         mainDict[i] = 'string'
+   return mainDict
 
 ##validation method - This is only for Output validation purpose
 def validatePluginData(result):
